@@ -35,23 +35,13 @@ See
 # Imports
 # =============================================================================
 
-import sys
+from importlib.metadata import version  # structure for Python 3.8 or higher
 
 from semantic_version import Version
 
 # noinspection PyUnresolvedReferences
 import cardinal_pythonlib.ensure_test_executed_correctly  # noqa: F401
 
-if sys.version_info > (3, 8):
-    # Python 3.8 or higher
-    # noinspection PyCompatibility
-    from importlib.metadata import version
-else:
-    try:
-        from importlib_metadata import version
-    except ImportError:
-        raise
-
 
 # =============================================================================
 # Report Python module versions
