@@ -150,7 +150,8 @@ def _start_process(
     proc = Popen(args, stdin=stdin, stdout=stdout, stderr=stderr)
     # proc = Popen(args, stdin=None, stdout=PIPE, stderr=STDOUT)
     # proc = Popen(args, stdin=None, stdout=PIPE, stderr=PIPE)
-    # Can't preserve colour: https://stackoverflow.com/questions/13299550/preserve-colored-output-from-python-os-popen  # noqa
+    # Can't preserve colour:
+    # https://stackoverflow.com/questions/13299550/preserve-colored-output-from-python-os-popen  # noqa: E501
     _g_processes.append(proc)
     _g_proc_args_list.append(args)
     return proc
@@ -198,7 +199,8 @@ def _wait_for_processes(
                             "Exiting top-level process (will kill "
                             "all other children)"
                         )
-                        fail()  # exit this process, therefore kill its children  # noqa
+                        fail()
+                        # ... exit this process, therefore kill its children
             except TimeoutExpired:
                 something_running = True
     _g_processes.clear()
@@ -300,7 +302,7 @@ def run_multiple_processes(
     #                 f"(indicating failure); its args were: "
     #                 f"{args_list[procidx]!r}")
     #             if die_on_failure:
-    #                 # https://stackoverflow.com/questions/29177490/how-do-you-kill-futures-once-they-have-started  # noqa
+    #                 # https://stackoverflow.com/questions/29177490/how-do-you-kill-futures-once-they-have-started  # noqa: E501
     #                 for f2 in future_to_procidx.keys():
     #                     f2.cancel()
     #                     # ... prevents more jobs being scheduled, except the
@@ -514,7 +516,7 @@ def mimic_user_input(
                          print_stdout=show_zip_output,
                          print_stdin=show_zip_output)
 
-    """  # noqa
+    """  # noqa: E501
     line_terminators = line_terminators or ["\n"]  # type: List[str]
     stdin_encoding = stdin_encoding or sys.getdefaultencoding()
     stdout_encoding = stdout_encoding or sys.getdefaultencoding()
